<instructions>
Get the entities for specified metrics

Entities are real-world concepts in a business such as customers,
transactions, and ad campaigns. Analysis is often focused around
specific entities, such as customer churn or
annual recurring revenue modeling.
</instructions>

<parameters>
metrics: List of metric names
</parameters>